"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefinitionProvider = void 0;
const vscode = require("vscode");
const path = require("path");
const brickwasm = require("@algoryx/brickwasm");
const fs = require("fs");
class DefinitionProvider {
    constructor(context) {
        this.context = context;
    }
    matchToken(token, position) {
        return token.line - 1 == position.line
            && token.column - 1 <= position.character
            && token.column - 1 + token.lexeme.length >= position.character;
    }
    provideDefinition(document, position, _) {
        const uri = fs.realpathSync.native(document.uri.fsPath);
        const { tokens, errors } = brickwasm.classify_bound_tokens(this.context, uri);
        let prev_was_import = false;
        for (const token of tokens) {
            if (prev_was_import && this.matchToken(token, position)) {
                const rel_path = token.lexeme.substring(2, token.lexeme.length - 1);
                const resolved_path = path.resolve(path.dirname(document.uri.fsPath), rel_path);
                const definition = {
                    uri: vscode.Uri.parse("brickimport:" + fs.realpathSync.native(resolved_path) + '.brick'),
                    range: new vscode.Range(new vscode.Position(0, 0), new vscode.Position(0, 0))
                };
                return definition;
            }
            if (token.type === 'Import') {
                prev_was_import = true;
            }
            else {
                prev_was_import = false;
            }
            // Check parent segments
            if (token.uri !== undefined
                && token.uri !== null
                && this.matchToken(token, position)) {
                const uri_line = token.uri_line === undefined ? 0 : (token.uri_line - 1);
                const definition = {
                    uri: vscode.Uri.file(fs.realpathSync.native(token.uri)),
                    range: new vscode.Range(new vscode.Position(uri_line, 0), new vscode.Position(uri_line, 0))
                };
                return definition;
            }
        }
        return undefined;
    }
}
exports.DefinitionProvider = DefinitionProvider;
//# sourceMappingURL=definitions-provider.js.map